# Trelis Development Tasks

## 🔥 High Priority
[] Push latest extension (update database).
[] Push and test latest server. Then test.
[] Fix Stripe pricing issue.
[x] Add Stripe subscriptions.
[x] Rules on usage of "Jupyter" brand.
[x] Implement session management for login. Ask about how things currently work for login and data querying on the dashboard AND in the extension.
[x] Fix scrolling issue.
[x] Insertion missing on first query (and later queries?) Can't replicate yet.
[x] Add link to jupyter.trelis.com for api key.
[x] Insertion is including new lines.
[x] Add a button to jump to the right cell.
[x] Ensure request limits are unique per user (not aggregated across users).

## 📈 Long Term Priority
[] Improve answer formatting into proper sections.
[] Help me navigate to top/bottom of latest answer when it’s long
[] Make it know about imports that aren’t installed?
[] Option to pop the chat out onto another monitor
[] You could give tips like what's the shortcut to open/close the right side trelis window
[] Cosmetic fix to new line at end of code blocks in assistant responses.
[] User message still has a bigger gap below it than above.

## Declined
[] Can I show cell numbers?

# Server side:

[x] Rename "magic link" to "sign-in link"
[x] Tidy right border.